@@ -2,6 +2,7 @@
 #define ABOUT_H
 
 #include <QDialog>
+#include <QtNetwork>
 
 namespace Ui {
     class About;
@@ -18,6 +19,9 @@ protected:
 
 private:
     Ui::About *ui;
+
+private slots:
+    void on_textBrowser_anchorClicked(QUrl );
 };
 
 #endif // ABOUT_H
