@@ -5,6 +5,7 @@
 #include <QSettings>
 #include <QModelIndex>
 #include <QMessageBox>
+#include "help.h"
 
 namespace Ui {
     class CurrencyEdit;
@@ -22,12 +23,15 @@ protected:
 private:
     Ui::CurrencyEdit *ui;    
     QSettings mvSettings;
+    bool mvPegged;
+    Help *helpWindow;
 
     void updateList();
     void clearFields();
 
 private slots:
-    void on_pushButton_Close_clicked();
+    void on_checkBox_Pegged_toggled(bool checked);
+    void on_actionHelp_triggered();
     void on_pushButton_Restore_clicked();
     void on_pushButton_Remove_clicked();
     void on_pushButton_Add_clicked();
