@@ -6,6 +6,7 @@
 #include <QModelIndex>
 #include <QInputDialog>
 #include "currencyedit.h"
+#include "help.h"
 
 namespace Ui {
     class CurrencySettings;
@@ -28,11 +29,13 @@ private:
     QString mvCurrency2;
     bool mvAutoUpdate;
     CurrencyEdit *currencyEdit;
+    Help *helpWindow;
 
     void displayRate();
     void updateList();
 
 private slots:
+    void on_actionHelp_triggered();
     void on_pushButton_Delete_clicked();
     void on_pushButton_Preset_clicked();
     void on_pushButton_Foreign_clicked();
