@@ -1,13 +1,15 @@
 #ifndef HELP_H
 #define HELP_H
 
-#include <QDialog>
+#include <QMainWindow>
+#include <QtNetwork>
+#include <QSettings>
 
 namespace Ui {
     class Help;
 }
 
-class Help : public QDialog {
+class Help : public QMainWindow {
     Q_OBJECT
 public:
     Help(QWidget *parent = 0);
@@ -18,6 +20,7 @@ protected:
 
 private:
     Ui::Help *ui;
+    QSettings mvSettings;
 };
 
 #endif // HELP_H
