@@ -469,7 +469,7 @@ void MainWindow::initialSettings()
         mvSettings.setValue("0Unit1", 0);
         mvSettings.setValue("0Unit2", 2);
         mvSettings.setValue("1UnitType", "Length");
-        mvSettings.setValue("1Unit1", 0);
+        mvSettings.setValue("1Unit1", 2);
         mvSettings.setValue("1Unit2", 4);
         mvSettings.setValue("2UnitType", "Speed");
         mvSettings.setValue("2Unit1", 2);
@@ -804,6 +804,21 @@ void MainWindow::updateCurrency()
     
     mvSettings.setValue("Currency/EUR", 1);
 
+    if (mvSettings.contains("CurrencyPeggedUSD")) {
+        double usd = mvSettings.value("Currency/USD").toDouble();
+        double rate;
+        double rateEuro;
+        mvSettings.beginGroup("CurrencyPeggedUSD");
+        QStringList pegged = mvSettings.allKeys();
+        mvSettings.endGroup();
+
+        foreach (QString currency, pegged) {
+            rate = mvSettings.value("CurrencyPeggedUSD/" + currency).toDouble();
+            rateEuro = rate * usd;
+            mvSettings.setValue("Currency/" + currency, rateEuro);
+        }
+    }
+
     QDate date = mvSettings.value("CurrencyTime").toDate();
     QString updated = date.toString();
 
@@ -985,8 +1000,9 @@ void MainWindow::on_pushButton_Currency2_clicked()
 
 void MainWindow::on_actionHelp_triggered()
 {
-    helpDialog = new Help;
-    helpDialog->exec();
+    mvSettings.setValue("Help", "Main");
+    helpWindow = new Help(this);
+    helpWindow->show();
 }
 
 void MainWindow::on_actionAbout_triggered()
