@@ -3,6 +3,7 @@
 
 #include <QMainWindow>
 #include <QSettings>
+#include "help.h"
 
 namespace Ui {
     class UnitSettings;
@@ -19,6 +20,7 @@ protected:
 
 private:
     Ui::UnitSettings *ui;
+    Help *helpWindow;
     QSettings mvSettings;
     QString mvUnit1;
     QString mvUnit2;
@@ -29,7 +31,7 @@ private:
     QString mvUnitType;
     QString mvSelectedType;
     QStringList mvUnits;
-    QStringList mvPresets;
+    QStringList mvPresets;    
 
     void initialSettings();
     void unitKey(int whichUnit);
@@ -38,6 +40,7 @@ private:
     void updatePresetList();
 
 private slots:
+    void on_actionHelp_triggered();
     void on_pushButton_Apply_clicked();
     void on_pushButton_Delete_clicked();
     void on_pushButton_Preset_clicked();
